==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/workloads/kotlin/inputs/LongTermSchedulePolicyArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.workloads.kotlin.inputs

import com.pulumi.azurenative.workloads.inputs.LongTermSchedulePolicyArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Long term policy schedule.
 * @property schedulePolicyType This property will be used as the discriminator for deciding the specific types in the polymorphic chain of types.
 * Expected value is 'LongTermSchedulePolicy'.
 */
public data class LongTermSchedulePolicyArgs(
    public val schedulePolicyType: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.workloads.inputs.LongTermSchedulePolicyArgs> {
    override fun toJava(): com.pulumi.azurenative.workloads.inputs.LongTermSchedulePolicyArgs =
        com.pulumi.azurenative.workloads.inputs.LongTermSchedulePolicyArgs.builder()
            .schedulePolicyType(schedulePolicyType.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [LongTermSchedulePolicyArgs].
 */
@PulumiTagMarker
public class LongTermSchedulePolicyArgsBuilder internal constructor() {
    private var schedulePolicyType: Output<String>? = null

    /**
     * @param value This property will be used as the discriminator for deciding the specific types in the polymorphic chain of types.
     * Expected value is 'LongTermSchedulePolicy'.
     */
    @JvmName("ybuviefxlbybatnf")
    public suspend fun schedulePolicyType(`value`: Output<String>) {
        this.schedulePolicyType = value
    }

    /**
     * @param value This property will be used as the discriminator for deciding the specific types in the polymorphic chain of types.
     * Expected value is 'LongTermSchedulePolicy'.
     */
    @JvmName("uufcktsjrdxldrxm")
    public suspend fun schedulePolicyType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.schedulePolicyType = mapped
    }

    internal fun build(): LongTermSchedulePolicyArgs = LongTermSchedulePolicyArgs(
        schedulePolicyType = schedulePolicyType ?: throw PulumiNullFieldException("schedulePolicyType"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/workloads/kotlin/inputs/LongTermSchedulePolicyArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.workloads.kotlin.inputs

import com.pulumi.azurenative.workloads.inputs.LongTermSchedulePolicyArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Long term policy schedule.
 * @property schedulePolicyType This property will be used as the discriminator for deciding the specific types in the polymorphic chain of types.
 * Expected value is 'LongTermSchedulePolicy'.
 */
public data class LongTermSchedulePolicyArgs(
    public val schedulePolicyType: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.workloads.inputs.LongTermSchedulePolicyArgs> {
    override fun toJava(): com.pulumi.azurenative.workloads.inputs.LongTermSchedulePolicyArgs =
        com.pulumi.azurenative.workloads.inputs.LongTermSchedulePolicyArgs.builder()
            .schedulePolicyType(schedulePolicyType.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [LongTermSchedulePolicyArgs].
 */
@PulumiTagMarker
public class LongTermSchedulePolicyArgsBuilder internal constructor() {
    private var schedulePolicyType: Output<String>? = null

    /**
     * @param value This property will be used as the discriminator for deciding the specific types in the polymorphic chain of types.
     * Expected value is 'LongTermSchedulePolicy'.
     */
    @JvmName("ddmjtjyduaaatbey")
    public suspend fun schedulePolicyType(`value`: Output<String>) {
        this.schedulePolicyType = value
    }

    /**
     * @param value This property will be used as the discriminator for deciding the specific types in the polymorphic chain of types.
     * Expected value is 'LongTermSchedulePolicy'.
     */
    @JvmName("ynremxsrlcqwrkmv")
    public suspend fun schedulePolicyType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.schedulePolicyType = mapped
    }

    internal fun build(): LongTermSchedulePolicyArgs = LongTermSchedulePolicyArgs(
        schedulePolicyType = schedulePolicyType ?: throw PulumiNullFieldException("schedulePolicyType"),
    )
}
